@@ -27,8 +27,8 @@ class Config : public Module {
     Q_OBJECT
 
 public:
-    explicit Config(QObject *parent = Q_NULLPTR);
-    virtual ~Config();
+    explicit Config(QObject *parent = nullptr);
+    ~Config() override;
 
 Q_SIGNALS:
     void pluginConfigChanged();
