@@ -40,7 +40,6 @@
 #include <time.h>
 
 // Local
-#include "Debug.h"
 #include "Application.h"
 #include "Activities.h"
 #include "resourcesadaptor.h"
@@ -285,7 +284,7 @@ Resources::~Resources()
 {
 }
 
-void Resources::RegisterResourceEvent(QString application, uint _windowId,
+void Resources::RegisterResourceEvent(const QString &application, uint _windowId,
                                       const QString &uri, uint event)
 {
     if (event > Event::LastEventType
